@@ -3,10 +3,10 @@
 // SPDX-License-Identifier: MIT
 
 use crate::{
+  error::Context,
   helpers::{app_paths::walk_builder, npm::PackageManager},
-  Result,
+  Error, ErrorExt, Result,
 };
-use anyhow::Context;
 use itertools::Itertools;
 use magic_string::MagicString;
 use oxc_allocator::Allocator;
@@ -101,7 +101,8 @@ pub fn migrate(frontend_dir: &Path) -> Result<Vec<String>> {
       let path = entry.path();
       let ext = path.extension().unwrap_or_default();
       if JS_EXTENSIONS.iter().any(|e| e == &ext) {
-        let js_contents = std::fs::read_to_string(path)?;
+        let js_contents =
+          std::fs::read_to_string(path).fs_context("failed to read JS file", path.to_path_buf())?;
         let new_contents = migrate_imports(
           path,
           &js_contents,
@@ -110,7 +111,7 @@ pub fn migrate(frontend_dir: &Path) -> Result<Vec<String>> {
         )?;
         if new_contents != js_contents {
           fs::write(path, new_contents)
-            .with_context(|| format!("Error writing {}", path.display()))?;
+            .fs_context("failed to write JS file", path.to_path_buf())?;
         }
       }
     }
@@ -166,7 +167,7 @@ fn migrate_imports<'a>(
     let allocator = Allocator::default();
     let ret = Parser::new(&allocator, js_source, source_type).parse();
     if !ret.errors.is_empty() {
-      anyhow::bail!(
+      crate::error::bail!(
         "failed to parse {} as valid Javascript/Typescript file",
         path.display()
       )
@@ -193,8 +194,12 @@ fn migrate_imports<'a>(
               new_module,
               Default::default(),
             )
-            .map_err(|e| anyhow::anyhow!("{e}"))
-            .context("failed to replace import source")?;
+            .map_err(|e| {
+              Error::Context(
+                "failed to replace import source".to_string(),
+                e.to_string().into(),
+              )
+            })?;
 
           // if module was pluginified, add to packages
           if let Some(plugin_name) = new_module.strip_prefix("@tauri-apps/plugin-") {
@@ -279,8 +284,12 @@ fn migrate_imports<'a>(
                   new_identifier,
                   Default::default(),
                 )
-                .map_err(|e| anyhow::anyhow!("{e}"))
-                .context("failed to rename identifier")?;
+                .map_err(|e| {
+                  Error::Context(
+                    "failed to rename identifier".to_string(),
+                    e.to_string().into(),
+                  )
+                })?;
             } else {
               // if None, we need to remove this specifier,
               // it will also be replaced with an import from its new plugin below
@@ -297,8 +306,12 @@ fn migrate_imports<'a>(
 
               magic_js_source
                 .remove(script_start + start as i64, script_start + end as i64)
-                .map_err(|e| anyhow::anyhow!("{e}"))
-                .context("failed to remove identifier")?;
+                .map_err(|e| {
+                  Error::Context(
+                    "failed to remove identifier".to_string(),
+                    e.to_string().into(),
+                  )
+                })?;
             }
           }
         }
@@ -322,8 +335,7 @@ fn migrate_imports<'a>(
       for import in imports_to_add {
         magic_js_source
           .append_right(script_start as u32 + start, &import)
-          .map_err(|e| anyhow::anyhow!("{e}"))
-          .context("failed to add import")?;
+          .map_err(|e| Error::Context("failed to add import".to_string(), e.to_string().into()))?;
       }
     }
 
@@ -331,8 +343,9 @@ fn migrate_imports<'a>(
       for stmt in stmts_to_add {
         magic_js_source
           .append_right(script_start as u32 + start, stmt)
-          .map_err(|e| anyhow::anyhow!("{e}"))
-          .context("failed to add statement")?;
+          .map_err(|e| {
+            Error::Context("failed to add statement".to_string(), e.to_string().into())
+          })?;
       }
     }
   }
