@@ -3,6 +3,7 @@
 // SPDX-License-Identifier: MIT
 
 use crate::{
+  error::{bail, Context, ErrorExt},
   helpers::{
     app_paths::tauri_dir,
     cargo_manifest::{crate_version, CargoLock, CargoManifest},
@@ -13,8 +14,6 @@ use crate::{
 
 use std::{fs::read_to_string, str::FromStr};
 
-use anyhow::{bail, Context};
-
 mod migrations;
 
 pub fn command() -> Result<()> {
@@ -22,17 +21,24 @@ pub fn command() -> Result<()> {
 
   let tauri_dir = tauri_dir();
 
-  let manifest_contents =
-    read_to_string(tauri_dir.join("Cargo.toml")).context("failed to read Cargo manifest")?;
-  let manifest = toml::from_str::<CargoManifest>(&manifest_contents)
-    .context("failed to parse Cargo manifest")?;
+  let manifest_contents = read_to_string(tauri_dir.join("Cargo.toml")).fs_context(
+    "failed to read Cargo manifest",
+    tauri_dir.join("Cargo.toml"),
+  )?;
+  let manifest = toml::from_str::<CargoManifest>(&manifest_contents).with_context(|| {
+    format!(
+      "failed to parse Cargo manifest {}",
+      tauri_dir.join("Cargo.toml").display()
+    )
+  })?;
 
   let workspace_dir = get_workspace_dir()?;
   let lock_path = workspace_dir.join("Cargo.lock");
   let lock = if lock_path.exists() {
-    let lockfile_contents = read_to_string(lock_path).context("failed to read Cargo lockfile")?;
-    let lock =
-      toml::from_str::<CargoLock>(&lockfile_contents).context("failed to parse Cargo lockfile")?;
+    let lockfile_contents =
+      read_to_string(&lock_path).fs_context("failed to read Cargo lockfile", &lock_path)?;
+    let lock = toml::from_str::<CargoLock>(&lockfile_contents)
+      .with_context(|| format!("failed to parse Cargo lockfile {}", lock_path.display()))?;
     Some(lock)
   } else {
     None
@@ -41,7 +47,8 @@ pub fn command() -> Result<()> {
   let tauri_version = crate_version(tauri_dir, Some(&manifest), lock.as_ref(), "tauri")
     .version
     .context("failed to get tauri version")?;
-  let tauri_version = semver::Version::from_str(&tauri_version)?;
+  let tauri_version = semver::Version::from_str(&tauri_version)
+    .with_context(|| format!("failed to parse tauri version {tauri_version}"))?;
 
   if tauri_version.major == 1 {
     migrations::v1::run().context("failed to migrate from v1")?;
