@@ -3,6 +3,7 @@
 // SPDX-License-Identifier: MIT
 
 use crate::{
+  error::Context,
   helpers::{prompts, template},
   Result,
 };
@@ -50,13 +51,15 @@ pub fn command(cli: Cli) -> Result<()> {
   match cli.command {
     Commands::Init(options) => {
       let plugin_name = match options.plugin_name {
-        None => super::infer_plugin_name(std::env::current_dir()?)?,
+        None => super::infer_plugin_name(
+          std::env::current_dir().context("failed to get current directory")?,
+        )?,
         Some(name) => name,
       };
 
       let out_dir = PathBuf::from(options.out_dir);
       if out_dir.join("android").exists() {
-        return Err(anyhow::anyhow!("android folder already exists"));
+        crate::error::bail!("Android folder already exists");
       }
 
       let plugin_id = prompts::input(
