@@ -3,13 +3,12 @@
 // SPDX-License-Identifier: MIT
 
 use super::PluginIosFramework;
-use crate::helpers::prompts;
 use crate::Result;
 use crate::{
-  helpers::{resolve_tauri_path, template},
+  error::{Context, ErrorExt},
+  helpers::{prompts, resolve_tauri_path, template},
   VersionMetadata,
 };
-use anyhow::Context;
 use clap::Parser;
 use handlebars::{to_json, Handlebars};
 use heck::{ToKebabCase, ToPascalCase, ToSnakeCase};
@@ -90,7 +89,14 @@ pub fn command(mut options: Options) -> Result<()> {
 
   let template_target_path = PathBuf::from(options.directory);
   let metadata = crates_metadata()?;
-  if std::fs::read_dir(&template_target_path)?.count() > 0 {
+  if std::fs::read_dir(&template_target_path)
+    .fs_context(
+      "failed to read target directory",
+      template_target_path.clone(),
+    )?
+    .count()
+    > 0
+  {
     log::warn!("Plugin dir ({:?}) not empty.", template_target_path);
   } else {
     let (tauri_dep, tauri_example_dep, tauri_build_dep, tauri_plugin_dep) =
@@ -247,15 +253,19 @@ pub fn command(mut options: Options) -> Result<()> {
   }
 
   let permissions_dir = template_target_path.join("permissions");
-  std::fs::create_dir(&permissions_dir)
-    .with_context(|| "failed to create `permissions` directory")?;
+  std::fs::create_dir(&permissions_dir).fs_context(
+    "failed to create `permissions` directory",
+    permissions_dir.clone(),
+  )?;
 
   let default_permissions = r#"[default]
 description = "Default permissions for the plugin"
 permissions = ["allow-ping"]
 "#;
-  std::fs::write(permissions_dir.join("default.toml"), default_permissions)
-    .with_context(|| "failed to write `permissions/default.toml`")?;
+  std::fs::write(permissions_dir.join("default.toml"), default_permissions).fs_context(
+    "failed to write default permissions file",
+    permissions_dir.join("default.toml"),
+  )?;
 
   Ok(())
 }
@@ -275,7 +285,7 @@ pub fn plugin_name_data(data: &mut BTreeMap<&'static str, serde_json::Value>, pl
 
 pub fn crates_metadata() -> Result<VersionMetadata> {
   serde_json::from_str::<VersionMetadata>(include_str!("../../metadata-v2.json"))
-    .map_err(Into::into)
+    .context("failed to parse Tauri version metadata")
 }
 
 pub fn generate_android_out_file(
