@@ -5,10 +5,10 @@
 package app.tauri.plugin
 
 import android.app.Activity
+import android.content.res.Configuration
 import android.content.Intent
 import android.content.pm.PackageManager
 import android.net.Uri
-import android.os.Bundle
 import android.webkit.WebView
 import androidx.activity.result.IntentSenderRequest
 import androidx.core.app.ActivityCompat
@@ -22,7 +22,6 @@ import app.tauri.annotation.InvokeArg
 import app.tauri.annotation.PermissionCallback
 import app.tauri.annotation.TauriPlugin
 import com.fasterxml.jackson.databind.ObjectMapper
-import org.json.JSONException
 import java.util.*
 import java.util.concurrent.CopyOnWriteArrayList
 
@@ -72,6 +71,28 @@ abstract class Plugin(private val activity: Activity) {
    */
   open fun onResume() {}
 
+  /**
+   * This event is called after onStop() when the current activity is being re-displayed to the user (the user has navigated back to it).
+   * It will be followed by onStart() and then onResume().
+   */
+  open fun onRestart() {}
+
+  /**
+   * This event is called when the app is no longer visible to the user.
+   * You will next receive either onRestart(), onDestroy(), or nothing, depending on later user activity.
+   */
+  open fun onStop() {}
+
+  /**
+   * This event is called before the activity is destroyed.
+   */
+  open fun onDestroy() {}
+
+  /**
+   * This event is called when a configuration change occurs but the app does not recreate the activity.
+   */
+  open fun onConfigurationChanged(newConfig: Configuration) {}
+
   /**
    * Start activity for result with the provided Intent and resolve calling the provided callback method name.
    *
@@ -148,6 +169,10 @@ abstract class Plugin(private val activity: Activity) {
     }
   }
 
+  fun hasListener(event: String): Boolean {
+    return !listeners[event].isNullOrEmpty()
+  }
+
   @Command
   open fun registerListener(invoke: Invoke) {
     val args = invoke.parseArgs(RegisterListenerArgs::class.java)
